@@ -120,7 +120,7 @@ class E6xIdentifierPreparer(compiler.IdentifierPreparer):
     def __init__(self, dialect):
         super(E6xIdentifierPreparer, self).__init__(
             dialect,
-            initial_quote='`',
+            initial_quote='"',
         )
 
 
